==> mingw-w64-clang-aarch64-glfw-3.3.9-1-any.pkg.tar.zst: clangarm64/share/doc/glfw/html/search/all_15.js <==
var searchData=
[
  ['ramp_0',['Gamma ramp',['../monitor_guide.html#monitor_gamma',1,'']]],
  ['ramp_20size_20of_20256_20may_20be_20rejected_1',['Gamma ramp size of 256 may be rejected',['../news.html#gamma_ramp_size_33',1,'']]],
  ['ramp_20support_2',['Gamma ramp support',['../news.html#news_30_gamma',1,'']]],
  ['raw_20mouse_20motion_3',['raw mouse motion',['../input_guide.html#raw_mouse_motion',1,'Raw mouse motion'],['../news.html#raw_motion_33',1,'Support for raw mouse motion']]],
  ['raw_20timer_20access_4',['Raw timer access',['../news.html#news_32_timer',1,'']]],
  ['readable_20name_5',['Human-readable name',['../monitor_guide.html#monitor_name',1,'']]],
  ['reading_20the_20timer_6',['Reading the timer',['../quick_guide.html#quick_timer',1,'']]],
  ['receiving_20input_20events_7',['Receiving input events',['../quick_guide.html#quick_key_input',1,'']]],
  ['red_8',['red',['../struct_g_l_f_wgammaramp.html#a2cce5d968734b685623eef913e635138',1,'GLFWgammaramp']]],
  ['redbits_9',['redBits',['../struct_g_l_f_wvidmode.html#a6066c4ecd251098700062d3b735dba1b',1,'GLFWvidmode']]],
  ['reentrancy_10',['Reentrancy',['../intro_guide.html#reentrancy',1,'']]],
  ['reference_11',['reference',['../group__context.html',1,'Context reference'],['../group__init.html',1,'Initialization, version and error reference'],['../group__input.html',1,'Input reference'],['../group__monitor.html',1,'Monitor reference'],['../group__vulkan.html',1,'Vulkan support reference'],['../group__window.html',1,'Window reference']]],
  ['refresh_12',['Window damage and refresh',['../window_guide.html#window_refresh',1,'']]],
  ['refreshrate_13',['refreshRate',['../struct_g_l_f_wvidmode.html#a791bdd6c7697b09f7e9c97054bf05649',1,'GLFWvidmode']]],
  ['rejected_14',['Gamma ramp size of 256 may be rejected',['../news.html#gamma_ramp_size_33',1,'']]],
  ['related_20attributes_15',['related attributes',['../window_guide.html#window_attribs_ctx',1,'Context related attributes'],['../window_guide.html#window_attribs_fb',1,'Framebuffer related attributes'],['../window_guide.html#window_attribs_wnd',1,'Window related attributes']]],
  ['related_20hints_16',['related hints',['../window_guide.html#window_hints_ctx',1,'Context related hints'],['../window_guide.html#window_hints_fb',1,'Framebuffer related hints'],['../window_guide.html#window_hints_mtr',1,'Monitor related hints'],['../window_guide.html#window_hints_wnd',1,'Window related hints']]],
  ['release_20behaviors_17',['Context release behaviors',['../news.html#news_31_release',1,'']]],
  ['release_20notes_18',['Release notes',['../news.html',1,'']]],
  ['release_20notes_20for_203_200_19',['Release notes for 3.0',['../news.html#news_30',1,'']]],
  ['release_20notes_20for_203_201_20',['Release notes for 3.1',['../news.html#news_31',1,'']]],
  ['release_20notes_20for_203_202_21',['Release notes for 3.2',['../news.html#news_32',1,'']]],
  ['release_20notes_20for_20version_203_203_22',['Release notes for version 3.3',['../news.html#news_33',1,'']]],
  ['removal_20of_20automatic_20event_20polling_23',['Removal of automatic event polling',['../moving_guide.html#moving_autopoll',1,'']]],
  ['removal_20of_20character_20actions_24',['Removal of character actions',['../moving_guide.html#moving_char_up',1,'']]],
  ['removal_20of_20glfwcall_20macro_25',['Removal of GLFWCALL macro',['../moving_guide.html#moving_stdcall',1,'']]],
  ['removal_20of_20image_20and_20texture_20loading_26',['Removal of image and texture loading',['../moving_guide.html#moving_image',1,'']]],
  ['removal_20of_20threading_20functions_27',['Removal of threading functions',['../moving_guide.html#moving_threads',1,'']]],
  ['removals_20in_203_203_28',['Removals in 3.3',['../news.html#removals_33',1,'']]],
  ['removed_29',['Windows XInput deadzone removed',['../news.html#xinput_deadzone_33',1,'']]],
  ['removed_20features_30',['Changed and removed features',['../moving_guide.html#moving_removed',1,'']]],
  ['renamed_20functions_31',['Renamed functions',['../moving_guide.html#moving_renamed_functions',1,'']]],
  ['renamed_20library_20and_20header_20file_32',['Renamed library and header file',['../moving_guide.html#moving_renamed_files',1,'']]],
  ['renamed_20tokens_33',['Renamed tokens',['../moving_guide.html#moving_renamed_tokens',1,'']]],
  ['renamed_20types_34',['Renamed types',['../moving_guide.html#moving_renamed_types',1,'']]],
  ['rendering_35',['rendering',['../news.html#content_scale_33',1,'Content scale queries for DPI-aware rendering'],['../news.html#news_31_autoiconify',1,'Simultaneous multi-monitor rendering']]],
  ['rendering_20with_20opengl_36',['Rendering with OpenGL',['../quick_guide.html#quick_render',1,'']]],
  ['repeat_20action_37',['Key repeat action',['../moving_guide.html#moving_repeat',1,'']]],
  ['replaced_20by_20scroll_20offsets_38',['Wheel position replaced by scroll offsets',['../moving_guide.html#moving_wheel',1,'']]],
  ['request_39',['request',['../news.html#attention_33',1,'User attention request'],['../window_guide.html#window_attention',1,'Window attention request']]],
  ['required_40',['CMake 3.0 or later is required',['../news.html#cmake_version_33',1,'']]],
  ['required_20to_20wait_20for_20events_41',['No window required to wait for events',['../news.html#wait_events_33',1,'']]],
  ['required_20vulkan_20extensions_42',['Querying required Vulkan extensions',['../vulkan_guide.html#vulkan_ext',1,'']]],
  ['requires_20dwm_20transparency_43',['Framebuffer transparency requires DWM transparency',['../news.html#caveat_fbtransparency_33',1,'']]],
  ['retrieving_20monitors_44',['Retrieving monitors',['../monitor_guide.html#monitor_monitors',1,'']]],
  ['right_20libraries_45',['Link with the right libraries',['../build_guide.html#build_link',1,'']]],
  ['roundtrip_20to_20server_46',['Empty events on X11 no longer roundtrip to server',['../news.html#emptyevents_33',1,'']]],
  ['run_20time_20context_20creation_20api_20selection_47',['Run-time context creation API selection',['../news.html#news_32_contextapi',1,'']]],
  ['run_20time_20version_48',['Run-time version',['../intro_guide.html#intro_version_runtime',1,'']]]
];

==> mingw-w64-clang-aarch64-glfw-3.3.9-2-any.pkg.tar.zst: clangarm64/share/doc/glfw/html/search/all_15.js <==
var searchData=
[
  ['ramp_0',['Gamma ramp',['../monitor_guide.html#monitor_gamma',1,'']]],
  ['ramp_20size_20of_20256_20may_20be_20rejected_1',['Gamma ramp size of 256 may be rejected',['../news.html#gamma_ramp_size_33',1,'']]],
  ['ramp_20support_2',['Gamma ramp support',['../news.html#news_30_gamma',1,'']]],
  ['raw_20mouse_20motion_3',['Raw mouse motion',['../input_guide.html#raw_mouse_motion',1,'Raw mouse motion'],['../news.html#raw_motion_33',1,'Support for raw mouse motion']]],
  ['raw_20timer_20access_4',['Raw timer access',['../news.html#news_32_timer',1,'']]],
  ['readable_20name_5',['Human-readable name',['../monitor_guide.html#monitor_name',1,'']]],
  ['reading_20the_20timer_6',['Reading the timer',['../quick_guide.html#quick_timer',1,'']]],
  ['receiving_20input_20events_7',['Receiving input events',['../quick_guide.html#quick_key_input',1,'']]],
  ['red_8',['red',['../struct_g_l_f_wgammaramp.html#a2cce5d968734b685623eef913e635138',1,'GLFWgammaramp']]],
  ['redbits_9',['redBits',['../struct_g_l_f_wvidmode.html#a6066c4ecd251098700062d3b735dba1b',1,'GLFWvidmode']]],
  ['reentrancy_10',['Reentrancy',['../intro_guide.html#reentrancy',1,'']]],
  ['reference_11',['reference',['../group__context.html',1,'Context reference'],['../group__init.html',1,'Initialization, version and error reference'],['../group__input.html',1,'Input reference'],['../group__monitor.html',1,'Monitor reference'],['../group__vulkan.html',1,'Vulkan support reference'],['../group__window.html',1,'Window reference']]],
  ['refresh_12',['Window damage and refresh',['../window_guide.html#window_refresh',1,'']]],
  ['refreshrate_13',['refreshRate',['../struct_g_l_f_wvidmode.html#a791bdd6c7697b09f7e9c97054bf05649',1,'GLFWvidmode']]],
  ['rejected_14',['Gamma ramp size of 256 may be rejected',['../news.html#gamma_ramp_size_33',1,'']]],
  ['related_20attributes_15',['Related attributes',['../window_guide.html#window_attribs_ctx',1,'Context related attributes'],['../window_guide.html#window_attribs_fb',1,'Framebuffer related attributes'],['../window_guide.html#window_attribs_wnd',1,'Window related attributes']]],
  ['related_20hints_16',['Related hints',['../window_guide.html#window_hints_ctx',1,'Context related hints'],['../window_guide.html#window_hints_fb',1,'Framebuffer related hints'],['../window_guide.html#window_hints_mtr',1,'Monitor related hints'],['../window_guide.html#window_hints_wnd',1,'Window related hints']]],
  ['release_20behaviors_17',['Context release behaviors',['../news.html#news_31_release',1,'']]],
  ['release_20notes_18',['Release notes',['../news.html',1,'']]],
  ['release_20notes_20for_203_200_19',['Release notes for 3.0',['../news.html#news_30',1,'']]],
  ['release_20notes_20for_203_201_20',['Release notes for 3.1',['../news.html#news_31',1,'']]],
  ['release_20notes_20for_203_202_21',['Release notes for 3.2',['../news.html#news_32',1,'']]],
  ['release_20notes_20for_20version_203_203_22',['Release notes for version 3.3',['../news.html#news_33',1,'']]],
  ['removal_20of_20automatic_20event_20polling_23',['Removal of automatic event polling',['../moving_guide.html#moving_autopoll',1,'']]],
  ['removal_20of_20character_20actions_24',['Removal of character actions',['../moving_guide.html#moving_char_up',1,'']]],
  ['removal_20of_20glfwcall_20macro_25',['Removal of GLFWCALL macro',['../moving_guide.html#moving_stdcall',1,'']]],
  ['removal_20of_20image_20and_20texture_20loading_26',['Removal of image and texture loading',['../moving_guide.html#moving_image',1,'']]],
  ['removal_20of_20threading_20functions_27',['Removal of threading functions',['../moving_guide.html#moving_threads',1,'']]],
  ['removals_20in_203_203_28',['Removals in 3.3',['../news.html#removals_33',1,'']]],
  ['removed_29',['Windows XInput deadzone removed',['../news.html#xinput_deadzone_33',1,'']]],
  ['removed_20features_30',['Changed and removed features',['../moving_guide.html#moving_removed',1,'']]],
  ['renamed_20functions_31',['Renamed functions',['../moving_guide.html#moving_renamed_functions',1,'']]],
  ['renamed_20library_20and_20header_20file_32',['Renamed library and header file',['../moving_guide.html#moving_renamed_files',1,'']]],
  ['renamed_20tokens_33',['Renamed tokens',['../moving_guide.html#moving_renamed_tokens',1,'']]],
  ['renamed_20types_34',['Renamed types',['../moving_guide.html#moving_renamed_types',1,'']]],
  ['rendering_35',['Rendering',['../news.html#content_scale_33',1,'Content scale queries for DPI-aware rendering'],['../news.html#news_31_autoiconify',1,'Simultaneous multi-monitor rendering']]],
  ['rendering_20with_20opengl_36',['Rendering with OpenGL',['../quick_guide.html#quick_render',1,'']]],
  ['repeat_20action_37',['Key repeat action',['../moving_guide.html#moving_repeat',1,'']]],
  ['replaced_20by_20scroll_20offsets_38',['Wheel position replaced by scroll offsets',['../moving_guide.html#moving_wheel',1,'']]],
  ['request_39',['Request',['../news.html#attention_33',1,'User attention request'],['../window_guide.html#window_attention',1,'Window attention request']]],
  ['required_40',['CMake 3.0 or later is required',['../news.html#cmake_version_33',1,'']]],
  ['required_20to_20wait_20for_20events_41',['No window required to wait for events',['../news.html#wait_events_33',1,'']]],
  ['required_20vulkan_20extensions_42',['Querying required Vulkan extensions',['../vulkan_guide.html#vulkan_ext',1,'']]],
  ['requires_20dwm_20transparency_43',['Framebuffer transparency requires DWM transparency',['../news.html#caveat_fbtransparency_33',1,'']]],
  ['retrieving_20monitors_44',['Retrieving monitors',['../monitor_guide.html#monitor_monitors',1,'']]],
  ['right_20libraries_45',['Link with the right libraries',['../build_guide.html#build_link',1,'']]],
  ['roundtrip_20to_20server_46',['Empty events on X11 no longer roundtrip to server',['../news.html#emptyevents_33',1,'']]],
  ['run_20time_20context_20creation_20api_20selection_47',['Run-time context creation API selection',['../news.html#news_32_contextapi',1,'']]],
  ['run_20time_20version_48',['Run-time version',['../intro_guide.html#intro_version_runtime',1,'']]]
];
